==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ColumnCustomFilterConditionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFilterConditionDescriptionMetadata } from "./ColumnFilterConditionDescriptionMetadata";
import { ColumnCustomFilterConditionDescription } from "./ColumnCustomFilterConditionDescription";
/**
 * @hidden
 */
var ColumnCustomFilterConditionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ColumnCustomFilterConditionDescriptionMetadata, _super);
    function ColumnCustomFilterConditionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnCustomFilterConditionDescriptionMetadata.b = function (a) {
        if (ColumnCustomFilterConditionDescriptionMetadata.a == null) {
            ColumnCustomFilterConditionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnCustomFilterConditionDescriptionMetadata.c(ColumnCustomFilterConditionDescriptionMetadata.a);
        }
        if (a.j(ColumnCustomFilterConditionDescriptionMetadata.a)) {
            return;
        }
        a.y(ColumnCustomFilterConditionDescriptionMetadata.a);
    };
    ColumnCustomFilterConditionDescriptionMetadata.c = function (a) {
        ColumnFilterConditionDescriptionMetadata.c(a);
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        a.item("Id", "(w:ID,wf:ID)String");
        a.item("Index", "Number:int");
    };
    ColumnCustomFilterConditionDescriptionMetadata.d = function (a) {
        ColumnCustomFilterConditionDescriptionMetadata.b(a);
        a.aa("ColumnCustomFilterCondition", function () { return new ColumnCustomFilterConditionDescription(); });
        a.z("ColumnCustomFilterCondition", ColumnCustomFilterConditionDescriptionMetadata.a);
    };
    ColumnCustomFilterConditionDescriptionMetadata.$t = markType(ColumnCustomFilterConditionDescriptionMetadata, 'ColumnCustomFilterConditionDescriptionMetadata');
    ColumnCustomFilterConditionDescriptionMetadata.a = null;
    return ColumnCustomFilterConditionDescriptionMetadata;
}(Base));
export { ColumnCustomFilterConditionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ColumnCustomFilterConditionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFilterConditionDescriptionMetadata } from "./ColumnFilterConditionDescriptionMetadata";
import { ColumnCustomFilterConditionDescription } from "./ColumnCustomFilterConditionDescription";
/**
 * @hidden
 */
var ColumnCustomFilterConditionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ColumnCustomFilterConditionDescriptionMetadata, _super);
    function ColumnCustomFilterConditionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnCustomFilterConditionDescriptionMetadata.b = function (a) {
        if (ColumnCustomFilterConditionDescriptionMetadata.a == null) {
            ColumnCustomFilterConditionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnCustomFilterConditionDescriptionMetadata.c(ColumnCustomFilterConditionDescriptionMetadata.a);
        }
        if (a.k(ColumnCustomFilterConditionDescriptionMetadata.a)) {
            return;
        }
        a.aa(ColumnCustomFilterConditionDescriptionMetadata.a);
    };
    ColumnCustomFilterConditionDescriptionMetadata.c = function (a) {
        ColumnFilterConditionDescriptionMetadata.c(a);
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        a.item("Id", "(w:ID,wf:ID)String");
        a.item("Index", "Number:int");
    };
    ColumnCustomFilterConditionDescriptionMetadata.d = function (a) {
        ColumnCustomFilterConditionDescriptionMetadata.b(a);
        a.ac("ColumnCustomFilterCondition", function () { return new ColumnCustomFilterConditionDescription(); });
        a.ab("ColumnCustomFilterCondition", ColumnCustomFilterConditionDescriptionMetadata.a);
    };
    ColumnCustomFilterConditionDescriptionMetadata.$t = markType(ColumnCustomFilterConditionDescriptionMetadata, 'ColumnCustomFilterConditionDescriptionMetadata');
    ColumnCustomFilterConditionDescriptionMetadata.a = null;
    return ColumnCustomFilterConditionDescriptionMetadata;
}(Base));
export { ColumnCustomFilterConditionDescriptionMetadata };
